@@ -1,11 +1,12 @@
 """Kernel connection helpers."""
+
 import json
 import struct
-import sys
+from typing import Any
 
 from jupyter_client.session import Session
 from tornado.websocket import WebSocketHandler
-from traitlets import Float, Instance, default
+from traitlets import Float, Instance, Unicode, default
 from traitlets.config import LoggingConfigurable
 
 try:
@@ -15,6 +16,8 @@ except ImportError:
 
 from jupyter_client.jsonutil import extract_dates
 
+from jupyter_server.transutils import _i18n
+
 from .abc import KernelWebsocketConnectionABC
 
 
@@ -36,8 +39,6 @@ def serialize_binary_message(msg):
     # don't modify msg or buffer list in-place
     msg = msg.copy()
     buffers = list(msg.pop("buffers"))
-    if sys.version_info < (3, 4):
-        buffers = [x.tobytes() for x in buffers]
     bmsg = json.dumps(msg, default=json_default).encode("utf8")
     buffers.insert(0, bmsg)
     nbufs = len(buffers)
@@ -88,14 +89,14 @@ def serialize_msg_to_ws_v1(msg_or_list, channel, pack=None):
     else:
         msg_list = msg_or_list
     channel = channel.encode("utf-8")
-    offsets: list = []
+    offsets: list[Any] = []
     offsets.append(8 * (1 + 1 + len(msg_list) + 1))
     offsets.append(len(channel) + offsets[-1])
     for msg in msg_list:
         offsets.append(len(msg) + offsets[-1])
     offset_number = len(offsets).to_bytes(8, byteorder="little")
     offsets = [offset.to_bytes(8, byteorder="little") for offset in offsets]
-    bin_msg = b"".join([offset_number] + offsets + [channel] + msg_list)
+    bin_msg = b"".join([offset_number, *offsets, channel, *msg_list])
     return bin_msg
 
 
@@ -113,6 +114,19 @@ def deserialize_msg_from_ws_v1(ws_msg):
 class BaseKernelWebsocketConnection(LoggingConfigurable):
     """A configurable base class for connecting Kernel WebSockets to ZMQ sockets."""
 
+    kernel_ws_protocol = Unicode(
+        None,
+        allow_none=True,
+        config=True,
+        help=_i18n(
+            "Preferred kernel message protocol over websocket to use (default: None). "
+            "If an empty string is passed, select the legacy protocol. If None, "
+            "the selected protocol will depend on what the front-end supports "
+            "(usually the most recent protocol supported by the back-end and the "
+            "front-end)."
+        ),
+    )
+
     @property
     def kernel_manager(self):
         """The kernel manager."""
@@ -149,19 +163,19 @@ class BaseKernelWebsocketConnection(LoggingConfigurable):
 
     async def connect(self):
         """Handle a connect."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def disconnect(self):
         """Handle a disconnect."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     def handle_incoming_message(self, incoming_msg: str) -> None:
         """Handle an incoming message."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
-    def handle_outgoing_message(self, stream: str, outgoing_msg: list) -> None:
+    def handle_outgoing_message(self, stream: str, outgoing_msg: list[Any]) -> None:
         """Handle an outgoing message."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
 
 KernelWebsocketConnectionABC.register(BaseKernelWebsocketConnection)
