@@ -2,6 +2,7 @@
 
 Preliminary documentation at https://github.com/ipython/ipython/wiki/IPEP-16%3A-Notebook-multi-directory-dashboard-and-URL-mapping#sessions-api
 """
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import asyncio
@@ -16,7 +17,7 @@ from jupyter_client.kernelspec import NoSuchKernel
 from jupyter_core.utils import ensure_async
 from tornado import web
 
-from jupyter_server.auth import authorized
+from jupyter_server.auth.decorator import authorized
 from jupyter_server.utils import url_path_join
 
 from ...base.handlers import APIHandler
@@ -52,12 +53,17 @@ class SessionRootHandler(SessionsAPIHandler):
         if model is None:
             raise web.HTTPError(400, "No JSON data provided")
 
-        if "notebook" in model and "path" in model["notebook"]:
+        if "notebook" in model:
             self.log.warning("Sessions API changed, see updated swagger docs")
-            model["path"] = model["notebook"]["path"]
             model["type"] = "notebook"
+            if "name" in model["notebook"]:
+                model["path"] = model["notebook"]["name"]
+            elif "path" in model["notebook"]:
+                model["path"] = model["notebook"]["path"]
 
         try:
+            # There is a high chance here that `path` is not a path but
+            # a unique session id
             path = model["path"]
         except KeyError as e:
             raise web.HTTPError(400, "Missing field in JSON data: path") from e
@@ -78,10 +84,10 @@ class SessionRootHandler(SessionsAPIHandler):
 
         exists = await ensure_async(sm.session_exists(path=path))
         if exists:
-            model = await sm.get_session(path=path)
+            s_model = await sm.get_session(path=path)
         else:
             try:
-                model = await sm.create_session(
+                s_model = await sm.create_session(
                     path=path,
                     kernel_name=kernel_name,
                     kernel_id=kernel_id,
@@ -101,10 +107,10 @@ class SessionRootHandler(SessionsAPIHandler):
             except Exception as e:
                 raise web.HTTPError(500, str(e)) from e
 
-        location = url_path_join(self.base_url, "api", "sessions", model["id"])
+        location = url_path_join(self.base_url, "api", "sessions", s_model["id"])
         self.set_header("Location", location)
         self.set_status(201)
-        self.finish(json.dumps(model, default=json_default))
+        self.finish(json.dumps(s_model, default=json_default))
 
 
 class SessionHandler(SessionsAPIHandler):
@@ -155,26 +161,42 @@ class SessionHandler(SessionsAPIHandler):
                 changes["kernel_id"] = kernel_id
             elif model["kernel"].get("name") is not None:
                 kernel_name = model["kernel"]["name"]
-                kernel_id = await sm.start_kernel_for_session(
-                    session_id,
-                    kernel_name=kernel_name,
-                    name=before["name"],
-                    path=before["path"],
-                    type=before["type"],
-                )
-                changes["kernel_id"] = kernel_id
+
+                try:
+                    kernel_id = await sm.start_kernel_for_session(
+                        session_id,
+                        kernel_name=kernel_name,
+                        name=before["name"],
+                        path=before["path"],
+                        type=before["type"],
+                    )
+                    changes["kernel_id"] = kernel_id
+                except Exception as e:
+                    # the error message may contain sensitive information, so we want to
+                    # be careful with it, thus we only give the short repr of the exception
+                    # and the full traceback.
+                    # this should be fine as we are exposing here the same info as when we start a new kernel
+                    msg = "The '%s' kernel could not be started: %s" % (
+                        kernel_name,
+                        repr(str(e)),
+                    )
+                    status_msg = "Error starting kernel %s" % kernel_name
+                    self.log.error("Error starting kernel: %s", kernel_name)
+                    self.set_status(501)
+                    self.finish(json.dumps({"message": msg, "short_message": status_msg}))
+                    return
 
         await sm.update_session(session_id, **changes)
-        model = await sm.get_session(session_id=session_id)
+        s_model = await sm.get_session(session_id=session_id)
 
-        if model["kernel"]["id"] != before["kernel"]["id"]:
+        if s_model["kernel"]["id"] != before["kernel"]["id"]:
             # kernel_id changed because we got a new kernel
             # shutdown the old one
             fut = asyncio.ensure_future(ensure_async(km.shutdown_kernel(before["kernel"]["id"])))
             # If we are not using pending kernels, wait for the kernel to shut down
             if not getattr(km, "use_pending_kernels", None):
                 await fut
-        self.finish(json.dumps(model, default=json_default))
+        self.finish(json.dumps(s_model, default=json_default))
 
     @web.authenticated
     @authorized
