@@ -1,5 +1,4 @@
-from jupyter_server.auth.security import passwd
-from jupyter_server.auth.security import passwd_check
+from jupyter_server.auth.security import passwd, passwd_check
 
 
 def test_passwd_structure():
@@ -25,7 +24,5 @@ def test_passwd_check_unicode():
     # GH issue #4524
     phash = "sha1:23862bc21dd3:7a415a95ae4580582e314072143d9c382c491e4f"
     assert passwd_check(phash, "łe¶ŧ←↓→")
-    phash = (
-        "argon2:$argon2id$v=19$m=10240,t=10,p=8$" "qjjDiZUofUVVnrVYxacnbA$l5pQq1bJ8zglGT2uXP6iOg"
-    )
+    phash = "argon2:$argon2id$v=19$m=10240,t=10,p=8$qjjDiZUofUVVnrVYxacnbA$l5pQq1bJ8zglGT2uXP6iOg"
     assert passwd_check(phash, "łe¶ŧ←↓→")
