@@ -67,18 +67,18 @@ mock_html = """
 """
 
 
-@pytest.fixture()
+@pytest.fixture
 def mock_template(jp_template_dir):
     index = jp_template_dir.joinpath("index.html")
     index.write_text(mock_html)
 
 
-@pytest.fixture()
+@pytest.fixture
 def extension_manager(jp_serverapp):
     return jp_serverapp.extension_manager
 
 
-@pytest.fixture()
+@pytest.fixture
 def config_file(jp_config_dir):
     """"""
     f = jp_config_dir.joinpath("jupyter_mockextension_config.py")
@@ -92,7 +92,7 @@ def jp_mockextension_cleanup():
     MockExtensionApp.clear_instance()
 
 
-@pytest.fixture()
+@pytest.fixture
 def contents_dir(tmp_path, jp_serverapp):
     return tmp_path / jp_serverapp.root_dir
 
@@ -113,7 +113,7 @@ dirs = [
 ]
 
 
-@pytest.fixture()
+@pytest.fixture
 def contents(contents_dir):
     # Create files in temporary directory
     paths: dict = {"notebooks": [], "textfiles": [], "blobs": [], "contents_dir": contents_dir}
@@ -134,7 +134,7 @@ def contents(contents_dir):
         paths["textfiles"].append(txtname.relative_to(contents_dir))
 
         # Create a random blob
-        blob = name.encode("utf-8") + b"\xFF"
+        blob = name.encode("utf-8") + b"\xff"
         blobname = p.joinpath(f"{name}.blob")
         blobname.write_bytes(blob)
         paths["blobs"].append(blobname.relative_to(contents_dir))
@@ -142,6 +142,6 @@ def contents(contents_dir):
     return paths
 
 
-@pytest.fixture()
+@pytest.fixture
 def folders():
     return list({item[0] for item in dirs})
